---
id: 402
properties:
- id: author
  name: Author
  type: string
  value: Andy Weir
- id: genre
  name: Genre
  type: string
  value: Science Fiction
- id: read
  name: Read
  type: boolean
  value: false
---

# Project Hail Mary

Recommended by several people. Same author as The Martian. On the to-read pile.